/*
 * AutistiList.java
 *
 * Created on 12 novembre 2005, 8.52
 */

import java.lang.*;
import java.io.*;
import java.util.Scanner;
import java.util.Iterator;
import java.util.LinkedList;

/**
 * La classe AutistiList fornisce una lista di autisti, letta da file automaticamente.
 * Implementa l'interfaccia Iterable per permettere l'uso del "for (item : collection)".
 *
 * @author Daniele Baracchi
 */
public class AutistiList implements Iterable<AutistiList.Autista> {
    
    // Inner class contenente semplicemente nome e telefono di un autista.
    public class Autista {
        public final String nome;
        public final String telefono;
        
        public Autista(String nome, String telefono) {
            this.nome = nome;
            this.telefono = telefono;
        }
    }
    
    // Lista interna per contenere i vari autisti
    protected LinkedList<Autista> autisti = new LinkedList<Autista>();
    
    /** Crea una nuova lista di autisti basandosi sul file il cui nome e' indicato come parametro */
    public AutistiList(String filename) {
        try {
            Scanner s = new Scanner(new File(filename));
            
            while (s.hasNext()) {
                String n = s.next(), t = s.next();
                autisti.add(new Autista(n, t));
            }
            
            s.close();
        } catch (FileNotFoundException ex) {
            System.out.println("File degli autisti non presente!");
            System.exit(0);
        } catch (IOException ex) {
            System.out.println("Errore di lettura da file!");
            System.exit(0);
        }
        
        System.out.println("File degli autisti letto con successo.");
    }
    
    public int length() {
        return autisti.size();
    }
    
    public Autista get(int i) {
        return autisti.get(i);
    }
    
    public Iterator<Autista> iterator() {
        return autisti.iterator();
    }
}
