/*
 * Linea.java
 *
 * Created on 12 novembre 2005, 8.42
 */

import java.lang.*;
import java.util.LinkedList;

/**
 * La classe Linea rappresenta una linea predefinita, ed in piu' fornisce alcuni metodi utili.
 * @author Daniele Baracchi
 */
public class Linea {
    
    // Semplice enum indicante la posizione relativa di due fermate.
    public enum Order {
        BEFORE, SAME, AFTER
    }
    
    // Lista contenente le fermate (rappresentate con un carattere)
    LinkedList<Character> fermate = new LinkedList<Character>();
    
    /** Crea una nuova Linea con le fermate specificate */
    public Linea(char [] flinea) {
        for (char f : flinea)
            fermate.add(f);
    }
    
    // Ritorna il numero della fermata specificata all'interno della linea (iniziando da 0)
    public int getOrdinal(char f) {
        return fermate.indexOf(f);
    }
    
    // Ritorna true se e solo se la fermata specificata appartiene alla linea.
    public boolean isInLinea(char fermata) {
        for (char c : fermate)
            if (c == fermata)
                return true;
        return false;
    }
    
    /* Compara due fermate all'interno della linea e ritorna il loro ordine relativo
     * (f1 BEFORE f2, f1 SAME f2, f1 AFTER f2)
     */
    public Order getOrder(char f1, char f2) {
        if (!(isInLinea(f1) && isInLinea(f2)))
            throw new RuntimeException("Le fermate non sono nella linea");
        
        if (f1 == f2)
            return Order.SAME;
        
        for (char f : fermate) {
            if (f == f1)
                return Order.BEFORE;
            if (f == f2)
                return Order.AFTER;
        }
        
        // Non dovremmo mai arrivare a questo punto
        return null;
    }
}
