/*
 * Orario.java
 *
 * Created on 12 novembre 2005, 10.34
 */

import java.lang.*;
import java.util.Scanner;
import java.util.regex.Pattern;

/**
 * Rappresenta un orario nel sistema, fornendo tutti i metodi per lavorarci serenamente.
 * Permette inoltre il confronto tra due orari.
 * @author Daniele Baracchi
 */
public class Orario implements Comparable<Orario> {

    // Interi contenenti ore e minuti (per semplicita')
    protected byte hours, minutes;
    
    // Vedi costruttore successivo
    public Orario(int h, int m) {
        this((byte) h, (byte) m);
    }
    
    /** Crea un nuovo Orario con ora e minuti specificati */
    public Orario(byte h, byte m) {
        if (h > 23 || m > 59)
            throw new IllegalArgumentException();
        
        hours = h;
        minutes = m;
    }
    
    // Crea un nuovo orario partendo da una stringa (formato hh:mm)
    public Orario(String s) {
        Scanner scan = new Scanner(s).useDelimiter(Pattern.compile(":"));
        
        hours = scan.nextByte();
        minutes = scan.nextByte();
    }
    
    // Ritorna le ore
    public byte getHours() {
        return hours;
    }
    
    // Imposta le ore
    public void setHours(byte h) {
        if (h > 23)
            throw new IllegalArgumentException();
        this.hours = h;
    }
    
    // Ritorna i minuti
    public byte getMinutes() {
        return minutes;
    }
    
    // Imposta i minuti
    public void setMinutes(byte m) {
        if (m > 59)
            throw new IllegalArgumentException();
        this.minutes = m;
    }
    
    // Somma due orari (8:30 + 4:10 = 12:40)
    public Orario add(Orario x) {
        return new Orario((byte) (this.getHours() + x.getHours()),
                (byte) (this.getMinutes() + x.getMinutes()));
    }
    
    // Somma un Orario con un numero di minuti (anche maggiore di 60)
    public Orario add(int val) {
        int m = this.getMinutes() + val % 60, h = this.getHours() + val / 60;
        if (m >= 60) {
            m -= 60;
            h++;
        }
        return new Orario(h, m);
    }
    
    // Esegue la differenza tra due orari
    public int difference(Orario x) {
        return Math.abs(this.asMinutes() - x.asMinutes());
    }
    
    // Ritorna l'orario sotto forma di minuti (hh*60 + mm)
    public int asMinutes() {
        return this.getMinutes() + this.getHours() * 60;
    }
    
    // Compara due orari
    public int compareTo(Orario x) {
        if (x.getHours() == this.getHours())
            return this.getMinutes() - x.getMinutes();
        return this.getHours() - x.getHours();
    }
    
    // Rappresenta l'orario nel formato hh:mm
    public String toString() {
        return (hours > 9 ? hours : "0" + hours) + ":" +
                (minutes > 9 ? minutes : "0" + minutes);
    }
    
}
