/*
 * RichiesteList.java
 *
 * Created on 12 novembre 2005, 9.50
 */

import java.lang.*;
import java.io.*;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Scanner;

/**
 * La classe Richieste fornisce una lista di richieste, letta da file automaticamente.
 * Implementa l'interfaccia Iterable per permettere l'uso del "for (item : collection)".
 *
 * @author Daniele Baracchi
 */
public class RichiesteList implements Iterable<Richiesta> {
    
    // Lista interna per contenere le varie richieste
    protected LinkedList<Richiesta> richieste = new LinkedList<Richiesta>();
    
    /** Crea una nuova lista di richieste basandosi sul file il cui nome e' indicato come parametro */
    public RichiesteList(String filename) {
        try {
            Scanner s = new Scanner(new File(filename));
            
            while (s.hasNext()) {
                String n = s.next(), t = s.next(), lt = s.next();
                int l = (lt.charAt(1) == '1' ? lt.charAt(0) - '0' : lt.charAt(0) - '0' + 4);
                char o = s.next().charAt(0), d = s.next().charAt(0);
                String p = s.next();
                richieste.add(new Richiesta(n, t, l-1, o, d, new Orario(p)));
            }
            
            s.close();
        } catch (FileNotFoundException ex) {
            System.out.println("File delle richieste non presente!");
            System.exit(0);
        } catch (IOException ex) {
            System.out.println("Errore di lettura da file!");
            System.exit(0);
        }
        
        System.out.println("File delle richieste letto con successo.");
    }
    
    public int length() {
        return richieste.size();
    }
    
    public Richiesta get(int i) {
        return richieste.get(i);
    }
    
    public Iterator<Richiesta> iterator() {
        return richieste.iterator();
    }
    
}
